Arbor includes code from the open source community. Thank you!

## fmt

{fmt} is an open-source formatting library providing a fast and safe alternative to C stdio and C++ iostreams.

https://github.com/fmtlib/fmt

## google-benchmark

A library to benchmark code snippets, similar to unit tests.

https://github.com/google/benchmark

## GoogleTest

GoogleTest is Google’s C++ testing and mocking framework.

https://github.com/google/googletest

## JSON for Modern C++

A header only C++11 json library, written by Niels Lohmann (GitHub user nlohmann).
MIT license.

https://github.com/nlohmann/json

## pybind11

pybind11 is a lightweight header-only library that exposes C++ types in Python and vice versa, mainly to create Python bindings of existing C++ code.

https://github.com/pybind/pybind11

## random123

The Random123 library is a collection of counter-based random number generators ("CBRNGs") for CPUs (C and C++) and GPUs (CUDA and OpenCL).

https://github.com/DEShawResearch/random123

## tinyopt

A header only C++ library for command line argument parsing, written by Stuart Yates.
BSD license.

https://github.com/halfflat/tinyopt

## Random123
A header only counter-based random number generator, written by DE Shaw research
BSD license.

https://www.deshawresearch.com/downloads/download_random123.cgi/

## Sphinx module for CMake

The CMake script cmake/FindSphinx.cmake is a modified version of a script from the LLVM
project.
BSD License.

http://llvm.org/

# PugiXML 

A simple and fast C++ XML processing library.
MIT License.

https://github.com/zeux/pugixml

## Transcendentals intrinsics

The numerical algorithms for the transcendentals intrinsics are based on the
scalar Cephes library. We have been explicitly granted permission by the author to
incorporate this material in our work.

http://www.netlib.org/cephes/
https://github.com/jeremybarnes/cephes (Github mirror)

Custom license (as it appears in the original `readme` from the project's page):

>Some software in this archive may be from the book _Methods and
>Programs for Mathematical Functions_ (Prentice-Hall or Simon & Schuster
>International, 1989) or from the Cephes Mathematical Library, a
>commercial product. In either event, it is copyrighted by the author.
>What you see here may be used freely but it comes with no support or
>guarantee.

## Example SWC morphology

The complex SWC file 'pyramidal.swc' used for testing is taken from NeuroMorpho.org,
with NeuroMorpho ID NMO_49821. The morphology comes from the paper:

> Hönigsperger, C., Marosi, M., Murphy, R., and Storm, J. F. (2015).
> Dorsoventral differences in Kv7/M-current and its impact on resonance,
> temporal summation and excitability in rat hippocampal pyramidal cells.
> _The Journal of Physiology_, 593(7), 1551–1580. doi:10.1113/jphysiol.2014.280826

NeuroMorpho.org is described in:

> Ascoli, G. A., Donohue, D. E., and Halavi, M. (2007).
> NeuroMorpho.Org: a central resource for neuronal morphologies.
> _Journal of Neuroscience_ 27(35), 9247–9251. doi:10.1523/JNEUROSCI.2055-07.2007

## Acknowledgements

This research has received funding from the European Unions Horizon 2020 Framework Programme for Research and
Innovation under the Specific Grant Agreement No. 720270 (Human Brain Project SGA1), Specific Grant Agreement
No. 785907 (Human Brain Project SGA2), and Specific Grant Agreement No. 945539 (Human Brain Project SGA3).
